Histogram of the simulated null gradient-norm statistics, with a vertical line at the selected \(\hat\lambda\).
Usage
# S3 method for class 'pic.lambda_pdb'
plot(x, breaks = 40L, ...)Histogram of the simulated null gradient-norm statistics, with a vertical line at the selected \(\hat\lambda\).
# S3 method for class 'pic.lambda_pdb'
plot(x, breaks = 40L, ...)